===========================
Dielectric constant modules
===========================

Epsilon bulk
============

Description
***********

.. automodule:: maicos.modules.epsilon.EpsilonBulk
    :members:
    :undoc-members:
    :show-inheritance:


Epsilon planar
==============

Description
***********

.. automodule:: maicos.modules.epsilon.EpsilonPlanar
    :members:
    :undoc-members:
    :show-inheritance:

Epsilon cylinder
================

Description
***********

.. automodule:: maicos.modules.epsilon.EpsilonCylinder
    :members:
    :undoc-members:
    :show-inheritance:

Dielectric spectrum
===================

Description
***********


.. automodule:: maicos.modules.epsilon.DielectricSpectrum
    :members:
    :undoc-members:
    :show-inheritance:
